import React from "react";
import { View, FlatList } from "react-native";
import Swipeout from "react-native-swipeout";

interface Props {
  [key: string]: any;
  tableData: Array<{ [key: string]: any }>;
  searchText?: string;
  searchTextForKey?: string;
}

export default class CustomTable extends React.Component<Props> {
  getRenderItem(rowData: any) {
    const { swipeLeftButtons, swipeRightButtons } = this.props;
    if (swipeLeftButtons || swipeRightButtons) {
      return (
        <Swipeout
          left={swipeLeftButtons ? swipeLeftButtons(rowData) : null}
          right={swipeRightButtons ? swipeRightButtons(rowData) : null}
          backgroundColor="transparent"
          {...this.props}
        >
          {this.props.renderRow(rowData)}
        </Swipeout>
      );
    } else {
      return this.props.renderRow(rowData);
    }
  }

  getTableData() {
    const { tableData, searchText, searchTextForKey } = this.props;
    if (
      searchTextForKey &&
      searchText &&
      searchText !== "" &&
      searchTextForKey !== ""
    ) {
      return tableData.filter((item: any) => {
        if (searchTextForKey in item) {
          return item[searchTextForKey]
            .toLowerCase()
            .includes(searchText.toLowerCase());
        } else {
          return;
        }
      });
    }

    return tableData;
  }

  render() {
    const { tableContainerStyle } = this.props;
    return (
      <View style={tableContainerStyle}>
        <FlatList
          data={this.getTableData()}
          renderItem={(rowData) => this.getRenderItem(rowData)}
          {...this.props}
        />
      </View>
    );
  }
}
